@@ -8,23 +8,23 @@ use Expect;
 use Try::Tiny;
 use namespace::autoclean;
 
-has host => ( is => 'ro', required => 0, );
+has host => (is => 'ro', required => 0,);
 
-has username => ( is => 'ro', required => 0, );
+has username => (is => 'ro', required => 0,);
 
-has password => ( is => 'ro', required => 0, );
+has password => (is => 'ro', required => 0,);
 
-has enpassword => ( is => 'ro', required => 0, );
+has enpassword => (is => 'ro', required => 0,);
 
-has proto => ( is => 'ro', required => 0, default => 'ssh', );
+has proto => (is => 'ro', required => 0, default => 'ssh',);
 
-has _login_ => ( is => 'ro', required => 0, default => 0, );
+has _login_ => (is => 'ro', required => 0, default => 0,);
 
 sub login {
   my $self = shift;
   return {success => 1} if $self->{_login_};
   try {
-    $self->connect() unless ( defined $self->{exp} );
+    $self->connect() unless (defined $self->{exp});
   }
   catch {
     if (/RSA modulus too small/mi) {
@@ -67,8 +67,8 @@ sub login {
 } ## end sub login
 
 sub connect {
-  my ( $self, $args ) = @_;
-  $args = "" unless ( defined $args );
+  my ($self, $args) = @_;
+  $args = "" unless (defined $args);
   my $host     = $self->{host};
   my $prompt   = '^\S+\s*[#\$]\s*\z';
   my $username = $self->{username};
@@ -87,34 +87,38 @@ sub connect {
   $exp->spawn($command) || die "Cannot spawn $command: $!\n";
   my @ret = $exp->expect(
     45,
-    [ qr/\(yes\/no\)\?\s*$/mi => sub {
+    [
+      qr/\(yes\/no\)\?\s*$/mi => sub {
         $exp->send("yes\n");
         exp_continue;
       }
     ],
-    [ qr/assword:\s*$/mi => sub {
+    [
+      qr/assword:\s*$/mi => sub {
         if ($loginFlag) {
           $loginFlag = 0;
           $exp->send("$password\n");
         }
         else {
-          croak "username or password is wrong!";
+          confess "username or password is wrong!";
         }
         exp_continue;
       }
     ],
-    [ qr/(ogin|name):\s*$/mi => sub {
+    [
+      qr/(ogin|name):\s*$/mi => sub {
         $exp->send("$username\n");
         exp_continue;
       }
     ],
-    [ qr/$prompt/m => sub {
+    [
+      qr/$prompt/m => sub {
         $self->{_login_} = 1;
       }
     ],
   );
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
   return 1;
 } ## end sub connect
@@ -124,7 +128,7 @@ sub getconfig {
   my @commands = ("show");
   my $config   = $self->execCommands(@commands);
   my $lines    = "";
-  if ( $config->{success} == 1 ) {
+  if ($config->{success} == 1) {
     $lines = $config->{result};
   }
   else {
@@ -134,31 +138,33 @@ sub getconfig {
 }
 
 sub send {
-  my ( $self, $command ) = @_;
+  my ($self, $command) = @_;
   my $exp = $self->{exp};
   $exp->send($command);
 }
 
 sub waitfor {
-  my ( $self, $prompt ) = @_;
-  $prompt = '^\S+\s*[#\$]\s*\z' unless ( defined $prompt );
+  my ($self, $prompt) = @_;
+  $prompt = '^\S+\s*[#\$]\s*\z' unless (defined $prompt);
   my $exp  = $self->{exp};
   my $buff = "";
   my @ret  = $exp->expect(
     15,
-    [ qr/^.+more.+$/mi => sub {
+    [
+      qr/^.+more.+$/mi => sub {
         $exp->send(" ");
         $buff .= $exp->before();
         exp_continue;
       }
     ],
-    [ qr/$prompt/mi => sub {
+    [
+      qr/$prompt/mi => sub {
         $buff .= $exp->before() . $exp->match();
       }
     ]
   );
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
   $buff =~ s/\r\n|\n+\n/\n/g;
   $buff =~ s/\x{08}+\s+\x{08}+//g;
@@ -166,21 +172,21 @@ sub waitfor {
 } ## end sub waitfor
 
 sub execCommands {
-  my ( $self, @commands ) = @_;
+  my ($self, @commands) = @_;
 
   # 配置下发前检查是否已成功登陆设备
-  if ( $self->{_login_} == 0 ) {
+  if ($self->{_login_} == 0) {
     my $ret = $self->login();
-    return $ret unless ( $ret->{success} );
+    return $ret unless ($ret->{success});
   }
 
   # 批处理下发队列
   my $result = "";
   for my $cmd (@commands) {
     next if $cmd =~ /^\s*$/;
-    $self->send( $cmd . "\n" );
+    $self->send($cmd . "\n");
     my $buff = $self->waitfor();
-    if ( $buff =~ /Unknown\s+action/mi ) {
+    if ($buff =~ /Unknown\s+action/mi) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     else {
