@@ -8,25 +8,25 @@ use Expect;
 use Try::Tiny;
 use namespace::autoclean;
 
-has host => ( is => 'ro', required => 0, );
+has host => (is => 'ro', required => 0,);
 
-has username => ( is => 'ro', required => 0, default => 'read' );
+has username => (is => 'ro', required => 0, default => 'read');
 
-has password => ( is => 'ro', required => 0, default => '', );
+has password => (is => 'ro', required => 0, default => '',);
 
-has enpassword => ( is => 'ro', required => 0, );
+has enpassword => (is => 'ro', required => 0,);
 
-has proto => ( is => 'ro', required => 0, default => 'ssh', );
+has proto => (is => 'ro', required => 0, default => 'ssh',);
 
-has _login_ => ( is => 'ro', required => 0, default => 0, );
+has _login_ => (is => 'ro', required => 0, default => 0,);
 
-has _enable_ => ( is => 'ro', required => 0, default => 0, );
+has _enable_ => (is => 'ro', required => 0, default => 0,);
 
 sub login {
   my $self = shift;
   return {success => 1} if $self->{_login_};
   try {
-    $self->connect() unless ( defined $self->{exp} );
+    $self->connect() unless (defined $self->{exp});
   }
   catch {
     if (/RSA modulus too small/mi) {
@@ -69,8 +69,8 @@ sub login {
 } ## end sub login
 
 sub connect {
-  my ( $self, $args ) = @_;
-  $args = "" unless ( defined $args );
+  my ($self, $args) = @_;
+  $args = "" unless (defined $args);
   my $host     = $self->{host};
   my $prompt   = '^\s*\S+[>\]]\s*$';
   my $username = $self->{username};
@@ -89,36 +89,40 @@ sub connect {
   $exp->spawn($command) || die "Cannot spawn $command: $!\n";
   my @ret = $exp->expect(
     45,
-    [ qr/\(yes\/no\)\?\s*$/mi => sub {
+    [
+      qr/\(yes\/no\)\?\s*$/mi => sub {
         $exp->send("yes\n");
         exp_continue;
       }
     ],
-    [ qr/assword:\s*$/mi => sub {
+    [
+      qr/assword:\s*$/mi => sub {
         if ($loginFlag) {
           $loginFlag = 0;
           $exp->send("$password\n");
         }
         else {
-          croak "username or password is wrong!";
+          confess "username or password is wrong!";
         }
         exp_continue;
       }
     ],
-    [ qr/(ogin|name):\s*$/mi => sub {
+    [
+      qr/(ogin|name):\s*$/mi => sub {
         $exp->send("$username\n");
         exp_continue;
       }
     ],
-    [ qr/$prompt/mi => sub {
+    [
+      qr/$prompt/mi => sub {
         $self->{_login_} = 1;
       }
     ],
   );
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
-  if ( $exp->match() =~ /\]\s*$/ ) {
+  if ($exp->match() =~ /\]\s*$/) {
     $self->{_enable_} = 1;
   }
   return 1;
@@ -129,7 +133,7 @@ sub getconfig {
   my @commands = ("dis cur");
   my $config   = $self->execCommands(@commands);
   my $lines    = "";
-  if ( $config->{success} == 1 ) {
+  if ($config->{success} == 1) {
     $lines = $config->{result};
   }
   else {
@@ -139,55 +143,61 @@ sub getconfig {
 }
 
 sub send {
-  my ( $self, $command ) = @_;
+  my ($self, $command) = @_;
   my $exp = $self->{exp};
   $exp->send($command);
 }
 
 sub waitfor {
-  my ( $self, $prompt ) = @_;
-  $prompt = '^.+[>\]]\s*\z' unless ( defined $prompt );
+  my ($self, $prompt) = @_;
+  $prompt = '^.+[>\]]\s*\z' unless (defined $prompt);
   my $exp  = $self->{exp};
   my $buff = "";
   my @ret  = $exp->expect(
     15,
-    [ qr/^.+more.+$/mi => sub {
+    [
+      qr/^.+more.+$/mi => sub {
         $buff .= $exp->before();
         $exp->send(" ");
         exp_continue;
       }
     ],
-    [ qr/Are\s+you\s+sure\?\s*\[Y\/N\]/mi => sub {
+    [
+      qr/Are\s+you\s+sure\?\s*\[Y\/N\]/mi => sub {
         $buff .= $exp->before() . $exp->match();
         $exp->send("Y\n");
         exp_continue;
       }
     ],
-    [ qr/press the enter key\)/mi => sub {
+    [
+      qr/press the enter key\)/mi => sub {
         $buff .= $exp->before() . $exp->match();
         $exp->send("\n");
         exp_continue;
       }
     ],
-    [ qr/overwrite\?\s*\[Y\/N\]/mi => sub {
+    [
+      qr/overwrite\?\s*\[Y\/N\]/mi => sub {
         $buff .= $exp->before() . $exp->match();
         $exp->send("Y\n");
         exp_continue;
       }
     ],
-    [ qr/^\%.+\z/mi => sub {
+    [
+      qr/^\%.+\z/mi => sub {
         $buff .= $exp->before();
         $exp->send(" ");
         exp_continue;
       }
     ],
-    [ qr/$prompt/mi => sub {
+    [
+      qr/$prompt/mi => sub {
         $buff .= $exp->before() . $exp->match();
       }
     ]
   );
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
   $buff =~ s/\x1b\[\d+D\s+\x1b\[\d+D//g;
   $buff =~ s/\r\n|\n+\n/\n/g;
@@ -197,28 +207,28 @@ sub waitfor {
 } ## end sub waitfor
 
 sub execCommands {
-  my ( $self, @commands ) = @_;
+  my ($self, @commands) = @_;
 
   # 优化配置下发自动保存配置逻辑
-  if ( scalar @commands > 1 ) {
+  if (scalar @commands > 1) {
     unshift @commands, "system-view";
-    push @commands, ( "return", "save" );
+    push @commands, ("return", "save");
   }
 
   # 下发配置前检查是否已成功登陆设备
-  if ( $self->{_login_} == 0 ) {
+  if ($self->{_login_} == 0) {
     my $ret = $self->login();
-    return $ret unless ( $ret->{success} );
+    return $ret unless ($ret->{success});
   }
-  $self->enable() unless ( $self->{_enable_} );
+  $self->enable() unless ($self->{_enable_});
 
   # 批处理下发队列
   my $result = "";
   for my $cmd (@commands) {
     next if $cmd =~ /$\s*$/;
-    $self->send( $cmd . "\n" );
+    $self->send($cmd . "\n");
     my $buff = $self->waitfor();
-    if ( $buff =~ /(^\s*\^|error:)/m ) {
+    if ($buff =~ /(^\s*\^|error:)/m) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     else {
@@ -237,35 +247,39 @@ sub enable {
   my $enableFlag = 1;
   my @ret        = $exp->expect(
     15,
-    [ qr/assword:\s*$/mi => sub {
+    [
+      qr/assword:\s*$/mi => sub {
         if ($enableFlag) {
           $enableFlag = 0;
           $exp->send("$enpasswd\n");
         }
         else {
-          croak "username or enpasswd is wrong!";
+          confess "username or enpasswd is wrong!";
         }
         exp_continue;
       }
     ],
-    [ qr/(ogin|name):\s*$/mi => sub {
+    [
+      qr/(ogin|name):\s*$/mi => sub {
         $exp->send("$username\n");
         exp_continue;
       }
     ],
-    [ qr/\(privilege\s+level\s+is.+>\s*\z\)/mi => sub {
+    [
+      qr/\(privilege\s+level\s+is.+>\s*\z\)/mi => sub {
         $self->{_enable_} = 1;
         return 1;
       }
     ],
-    [ qr/\(privilege\s+is\s+.+>\s*\z\)/mi => sub {
+    [
+      qr/\(privilege\s+is\s+.+>\s*\z\)/mi => sub {
         $self->{_enable_} = 1;
         return 1;
       }
     ]
   );
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
 } ## end sub enable
 
