@@ -8,25 +8,25 @@ use Expect;
 use Try::Tiny;
 use namespace::autoclean;
 
-has host => ( is => 'ro', required => 0, );
+has host => (is => 'ro', required => 0,);
 
-has username => ( is => 'ro', required => 0, default => 'read' );
+has username => (is => 'ro', required => 0, default => 'read');
 
-has password => ( is => 'ro', required => 0, default => '', );
+has password => (is => 'ro', required => 0, default => '',);
 
-has enpassword => ( is => 'ro', required => 0, );
+has enpassword => (is => 'ro', required => 0,);
 
-has proto => ( is => 'ro', required => 0, default => 'ssh', );
+has proto => (is => 'ro', required => 0, default => 'ssh',);
 
-has _login_ => ( is => 'ro', required => 0, default => 0, );
+has _login_ => (is => 'ro', required => 0, default => 0,);
 
-has _enable_ => ( is => 'ro', required => 0, default => 0, );
+has _enable_ => (is => 'ro', required => 0, default => 0,);
 
 sub login {
   my $self = shift;
   return {success => 1} if $self->{_login_};
   try {
-    $self->connect() unless ( defined $self->{exp} );
+    $self->connect() unless (defined $self->{exp});
   }
   catch {
     if (/RSA modulus too small/mi) {
@@ -69,8 +69,8 @@ sub login {
 } ## end sub login
 
 sub connect {
-  my ( $self, $args ) = @_;
-  $args = "" unless ( defined $args );
+  my ($self, $args) = @_;
+  $args = "" unless (defined $args);
   my $username = $self->{username};
   my $password = $self->{password};
   my $host     = $self->{host};
@@ -88,34 +88,38 @@ sub connect {
   $exp->spawn($command) || die "Cannot spawn $command: $!\n";
   my @ret = $exp->expect(
     45,
-    [ qr/\(yes\/no\)\?\s*$/mi => sub {
+    [
+      qr/\(yes\/no\)\?\s*$/mi => sub {
         $exp->send("yes\n");
         exp_continue;
       }
     ],
-    [ qr/assword:\s*$/mi => sub {
+    [
+      qr/assword:\s*$/mi => sub {
         if ($loginFlag) {
           $loginFlag = 0;
           $exp->send("$password\n");
         }
         else {
-          croak "username or password is wrong!";
+          confess "username or password is wrong!";
         }
         exp_continue;
       }
     ],
-    [ qr/(ogin|name):\s*$/mi => sub {
+    [
+      qr/(ogin|name):\s*$/mi => sub {
         $exp->send("$username\n");
         exp_continue;
       }
     ],
-    [ qr/$prompt/mi => sub {
+    [
+      qr/$prompt/mi => sub {
         $self->{_login_} = 1;
       }
     ],
   );
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
 } ## end sub connect
 
@@ -124,7 +128,7 @@ sub getconfig {
   my @commands = ("show config | display set | no-more");
   my $config   = $self->execCommands(@commands);
   my $lines    = "";
-  if ( $config->{success} == 1 ) {
+  if ($config->{success} == 1) {
     $lines = $config->{result};
   }
   else {
@@ -134,55 +138,57 @@ sub getconfig {
 }
 
 sub send {
-  my ( $self, $command ) = @_;
+  my ($self, $command) = @_;
   my $exp = $self->{exp};
   $exp->send($command);
 }
 
 sub waitfor {
-  my ( $self, $prompt ) = @_;
-  $prompt = '^.+[>#]\s*\z' unless ( defined $prompt );
+  my ($self, $prompt) = @_;
+  $prompt = '^.+[>#]\s*\z' unless (defined $prompt);
   my $exp  = $self->{exp};
   my $buff = "";
   my @ret  = $exp->expect(
     30,
-    [ qr/^.+more.+$/mi => sub {
+    [
+      qr/^.+more.+$/mi => sub {
         $exp->send(" ");
         $buff .= $exp->before();
         exp_continue;
       }
     ],
-    [ qr/$prompt/m => sub {
+    [
+      qr/$prompt/m => sub {
         $buff .= $exp->before() . $exp->match();
       }
     ]
   );
-  if ( defined $ret[1] ) {
+  if (defined $ret[1]) {
     confess $ret[3] . $ret[1];
   }
   return $buff;
 } ## end sub waitfor
 
 sub execCommands {
-  my ( $self, $commands ) = @_;
+  my ($self, $commands) = @_;
 
   #if ( @{ $commands } > 0 ) {
   # unshift @{ $commands }, "configure";
   # push @{ $commands }, "commit"
   #}
   # 配置下发前检查是否成功登陆主机
-  if ( $self->{_login_} == 0 ) {
+  if ($self->{_login_} == 0) {
     my $ret = $self->login();
-    return $ret unless ( $ret->{success} );
+    return $ret unless ($ret->{success});
   }
 
   # 批处理下发队列
   my $result = "";
-  for my $cmd ( @{$commands} ) {
+  for my $cmd (@{$commands}) {
     next if $cmd =~ /^\s*$/;
-    $self->send( $cmd . "\n" );
+    $self->send($cmd . "\n");
     my $buff = $self->waitfor();
-    if ( $buff =~ /Invalid input detected\s+.+\^/mi ) {
+    if ($buff =~ /Invalid input detected\s+.+\^/mi) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     else {
