@@ -17,11 +17,11 @@ object-policy ip tttt
 return
 [H3C-object-policy-ip-tttt]';
 
-if ( $string =~ /rule\s+(?<ruleId>\d+)\s+pass[^\n]+\n\s*#/si ) {
-  say $+{ruleId};
+if ($string =~ /rule\s+(?<ruleId>\d+)\s+pass[^\n]+\n\s*#/si) {
+  print $+{ruleId};
 
 }
 else {
-  say "not match";
+  print "not match";
 }
 
