@@ -18,25 +18,25 @@ my $connection = new Net::SSH::Expect(
 my $prompt;
 eval { $prompt = $connection->login(1) };
 if ($@) {
-  say "connect  faile!$@";
+  print "connect  faile!$@";
 
 }
-elsif ( $prompt =~ /[>,#]\s*/ ) {
-  say dumper $prompt;
+elsif ($prompt =~ /[>,#]\s*/) {
+  print dumper $prompt;
   my $curtime = strftime "%Y-%m-%d %H:%M:%S", localtime;
-  say "$curtime login  success!";
+  print "$curtime login  success!";
 }
 $connection->send('sh run');
 $connection->waitfor('(?m:#\z)');
 my $lines = $connection->before();
-say $lines;
+print $lines;
 my $buf = $lines;
-while ( $lines =~ /More/mi ) {
+while ($lines =~ /More/mi) {
   $connection->get_expect()->send(" ");
-  $connection->waitfor( '#\z', 0.1 );
+  $connection->waitfor('#\z', 0.1);
   $lines = $connection->before();
   $buf .= $lines;
   last if $lines =~ /#\s*\z/mi;
 }
 
-say dumper $lines;
+print dumper $lines;
